@@ -70,11 +70,17 @@
 void
 nautilus_drag_init (NautilusDragInfo     *drag_info,
 		    const GtkTargetEntry *drag_types,
-		    int                   drag_type_count)
+		    int                   drag_type_count,
+		    gboolean              add_text_targets)
 {
 	drag_info->target_list = gtk_target_list_new (drag_types,
 						   drag_type_count);
 
+	if (add_text_targets) {
+		gtk_target_list_add_text_targets (drag_info->target_list,
+						  NAUTILUS_ICON_DND_TEXT);
+	}
+
 	drag_info->drop_occured = FALSE;
 	drag_info->need_to_destroy = FALSE;
 }
@@ -303,6 +309,7 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	int *action)
 {
 	gboolean same_fs;
+	gboolean target_is_source_parent;
 	GnomeVFSURI *target_uri;
 	GnomeVFSURI *dropped_uri;
 	GdkDragAction actions;
@@ -373,14 +380,16 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	/* Compare the first dropped uri with the target uri for same fs match. */
 	dropped_uri = gnome_vfs_uri_new (((NautilusDragSelectionItem *)items->data)->uri);
 	same_fs = TRUE;
+	target_is_source_parent = FALSE;
 
 	if (dropped_uri != NULL) {
 		gnome_vfs_check_same_fs_uris (dropped_uri, target_uri, &same_fs);
+		target_is_source_parent = gnome_vfs_uri_is_parent (target_uri, dropped_uri, FALSE);
 		gnome_vfs_uri_unref (dropped_uri);
 	}
 	gnome_vfs_uri_unref (target_uri);
 	
-	if (same_fs) {
+	if (same_fs || target_is_source_parent) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		} else {
@@ -628,17 +637,17 @@ nautilus_drag_drop_action_ask (GtkWidget *widget,
 	menu = gtk_menu_new ();
 	gtk_menu_set_screen (GTK_MENU (menu), gtk_widget_get_screen (widget));
 	
-	append_drop_action_menu_item (menu, _("_Move here"),
+	append_drop_action_menu_item (menu, _("_Move Here"),
 				      GDK_ACTION_MOVE,
 				      (actions & GDK_ACTION_MOVE) != 0,
 				      &damd);
 
-	append_drop_action_menu_item (menu, _("_Copy here"),
+	append_drop_action_menu_item (menu, _("_Copy Here"),
 				      GDK_ACTION_COPY,
 				      (actions & GDK_ACTION_COPY) != 0,
 				      &damd);
 	
-	append_drop_action_menu_item (menu, _("_Link here"),
+	append_drop_action_menu_item (menu, _("_Link Here"),
 				      GDK_ACTION_LINK,
 				      (actions & GDK_ACTION_LINK) != 0,
 				      &damd);
