@@ -416,6 +416,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 	char *to_path;
 	char *to_text;
 	char *progress_label_text;
+	const char *hostname;
 	const char *from_prefix;
 	const char *to_prefix;
 	GnomeVFSURI *uri;
@@ -432,6 +433,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 		uri = gnome_vfs_uri_new (from_uri);
 		item = gnome_vfs_uri_extract_short_name (uri);
 		from_path = gnome_vfs_uri_extract_dirname (uri);
+		hostname = NULL;
 
 		/* remove the last '/' */
 		length = strlen (from_path);
@@ -439,12 +441,15 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			from_path [length - 1] = '\0';
 		}
 
-		if (g_str_has_prefix (from_uri, "file://")) {
-			from_text = from_path;
-		} else {
+		if (!gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		if (hostname) {
 			from_text = g_strdup_printf (_("%s on %s"),
-				from_path, gnome_vfs_uri_get_host_name (uri));
+				from_path, hostname);
 			g_free (from_path);
+		} else {
+			from_text = from_path;
 		}
 		
 		gnome_vfs_uri_unref (uri);
@@ -457,6 +462,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 	if (to_uri != NULL) {
 		uri = gnome_vfs_uri_new (to_uri);
 		to_path = gnome_vfs_uri_extract_dirname (uri);
+		hostname = NULL;
 
 		/* remove the last '/' */
 		length = strlen (to_path);
@@ -464,12 +470,15 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			to_path [length - 1] = '\0';
 		}
 
-		if (g_str_has_prefix (to_uri, "file://")) {
-			to_text = to_path;
-		} else {
+		if (!gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		if (hostname) {
 			to_text = g_strdup_printf (_("%s on %s"),
-				to_path, gnome_vfs_uri_get_host_name (uri));
+				to_path, hostname);
 			g_free (to_path);
+		} else {
+			to_text = to_path;
 		}
 
 		gnome_vfs_uri_unref (uri);
@@ -914,7 +923,6 @@ handle_transfer_vfs_error (const GnomeVFSXferProgressInfo *progress_info,
 	char *detail;
 	char *formatted_source_name;
 	char *formatted_target_name;
-	const char *dialog_title;
 	NautilusFileOperationsErrorKind error_kind;
 	NautilusFileOperationsErrorLocation error_location;
 	
@@ -1008,40 +1016,18 @@ handle_transfer_vfs_error (const GnomeVFSXferProgressInfo *progress_info,
 				    progress_info->vfs_status,
 				    &text, &detail);
 
-		switch (transfer_info->kind) {
-		case TRANSFER_COPY:
-		case TRANSFER_DUPLICATE:
-			dialog_title = _("Error While Copying");
-			break;
-		case TRANSFER_MOVE:
-			dialog_title = _("Error While Moving");
-			break;
-		case TRANSFER_LINK:
-			dialog_title = _("Error While Linking");
-			break;
-		case TRANSFER_DELETE:
-		case TRANSFER_EMPTY_TRASH:
-		case TRANSFER_MOVE_TO_TRASH:
-			dialog_title = _("Error While Deleting");
-			break;
-		default:
-			dialog_title = NULL;
-			break;
-		}
-
 		if (error_location == ERROR_LOCATION_TARGET ||
 		    error_kind == ERROR_SOURCE_IN_TARGET) {
 			/* We can't continue, just tell the user. */
 			eel_run_simple_dialog (parent_for_error_dialog (transfer_info),
-				TRUE, GTK_MESSAGE_ERROR, text, detail, dialog_title, GTK_STOCK_OK, NULL);
+				TRUE, GTK_MESSAGE_ERROR, text, detail, GTK_STOCK_OK, NULL);
 			error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 
 		} else if (progress_info->files_total == 1) {
 			error_dialog_button_pressed = eel_run_simple_dialog
 				(parent_for_error_dialog (transfer_info), TRUE, 
 				 GTK_MESSAGE_ERROR, text, 
-				 detail, dialog_title,
-				 GTK_STOCK_CANCEL, _("_Retry"), NULL);
+				 detail, GTK_STOCK_CANCEL, _("_Retry"), NULL);
 
 			switch (error_dialog_button_pressed) {
 			case 0:
@@ -1058,8 +1044,7 @@ handle_transfer_vfs_error (const GnomeVFSXferProgressInfo *progress_info,
 			error_dialog_button_pressed = eel_run_simple_dialog
 				(parent_for_error_dialog (transfer_info), TRUE, 
 				 GTK_MESSAGE_ERROR, text, 
-				 detail, dialog_title,
-				 _("_Skip"), GTK_STOCK_CANCEL, _("_Retry"), NULL);
+				 detail, _("_Skip"), GTK_STOCK_CANCEL, _("_Retry"), NULL);
 
 			switch (error_dialog_button_pressed) {
 			case 0:
@@ -1164,8 +1149,10 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 					   "to copy the item, rename it and try again.");
 		}
 		
-		eel_run_simple_dialog (parent_for_error_dialog (transfer_info), TRUE, GTK_MESSAGE_ERROR, primary_text, secondary_text,
-				       _("Unable to Replace File"), GTK_STOCK_OK, NULL, NULL);
+		eel_run_simple_dialog (parent_for_error_dialog (transfer_info),
+				       TRUE, GTK_MESSAGE_ERROR,
+				       primary_text, secondary_text,
+				       GTK_STOCK_OK, NULL);
 
 		g_free (primary_text);
 		g_free (formatted_name);
@@ -1207,7 +1194,6 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 			 GTK_MESSAGE_QUESTION, 
 			 text, 
 			 secondary_text, 
-			 _("Conflict While Copying"),
 			 _("_Skip"), _("_Replace"), NULL);
 		g_free (text);	 
 
@@ -1226,7 +1212,6 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 		result = eel_run_simple_dialog
 			(parent_for_error_dialog (transfer_info), TRUE, GTK_MESSAGE_QUESTION, text, 
 			 secondary_text, 
-			 _("Conflict While Copying"),
 			 _("S_kip All"), _("Replace _All"), _("_Skip"), _("_Replace"), NULL);
 		g_free (text);
 
@@ -2102,7 +2087,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 				 ? _("You cannot copy items into the trash.")
 				 : _("You cannot create links inside the trash."),
 				 _("Files and folders can only be moved into the trash."), 
-				 NULL,
 				 GTK_STOCK_OK, NULL);
 			result = GNOME_VFS_ERROR_NOT_PERMITTED;
 		}
@@ -2128,9 +2112,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 						 ? _("You cannot move this trash folder.")
 						 : _("You cannot copy this trash folder."),
 					 _("A trash folder is used for storing items moved to the trash."),
-					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0)
-						 ? _("Can't Change Trash Location")
-						 : _("Can't Copy Trash"),
 					 GTK_STOCK_OK, NULL, NULL);
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
@@ -2157,10 +2138,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 ? _("You cannot move a folder into itself.")
 					 : _("You cannot copy a folder into itself."), 
 					 _("The destination folder is inside the source folder."), 
-					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0) 
-					 ? _("Can't Move Into Self")
-					 : _("Can't Copy Into Self"),
-					 GTK_STOCK_OK, NULL, NULL);			
+					 GTK_STOCK_OK, NULL, NULL);
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
 				break;
@@ -2174,7 +2152,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 GTK_MESSAGE_ERROR,
 					 _("You cannot copy a file over itself."),
 					 _("The destination and source are the same file."), 
-					 _("Can't Copy Over Self"), 
 					 GTK_STOCK_OK, NULL, NULL);			
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
@@ -2238,7 +2215,7 @@ handle_new_folder_vfs_error (const GnomeVFSXferProgressInfo *progress_info, NewF
 		error_string_to_free = (char *)error_string;
 	}
 	
-	eel_show_error_dialog (_("Error creating new folder."), error_string, _("Error Creating New Folder"),
+	eel_show_error_dialog (_("Error creating new folder."), error_string,
 				    GTK_WINDOW (gtk_widget_get_toplevel (state->parent_view)));
 	
 	g_free (error_string_to_free);
@@ -2398,7 +2375,7 @@ handle_new_file_vfs_error (const GnomeVFSXferProgressInfo *progress_info, NewFil
 		error_string_to_free = (char *)error_string;
 	}
 	
-	eel_show_error_dialog (_("Error creating new document."), error_string, _("Error Creating New Document"),
+	eel_show_error_dialog (_("Error creating new document."), error_string,
 			       GTK_WINDOW (gtk_widget_get_toplevel (state->parent_view)));
 	
 	g_free (error_string_to_free);
