@@ -27,7 +27,6 @@
 #include "fm-error-reporting.h"
 
 #include <string.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs-result.h>
 #include <libnautilus-private/nautilus-file.h>
@@ -37,39 +36,44 @@
 #define NEW_NAME_TAG "Nautilus: new name"
 #define MAXIMUM_DISPLAYED_FILE_NAME_LENGTH	50
 
-static void cancel_rename (NautilusFile *file);
+static void cancel_rename (NautilusFile *file, gboolean stop_timer);
 
 void
 fm_report_error_loading_directory (NautilusFile *file,
 			           GnomeVFSResult error,
+				   const char *error_message,
 			           GtkWindow *parent_window)
 {
 	char *file_name;
 	char *message;
 
-	if (error == GNOME_VFS_OK) {
+	if (error_message == NULL && error == GNOME_VFS_OK) {
 		return;
 	}
 
 	file_name = nautilus_file_get_display_name (file);
 
-	switch (error) {
-	case GNOME_VFS_ERROR_ACCESS_DENIED:
-		message = g_strdup_printf (_("You do not have the permissions necessary to view the contents of \"%s\"."),
-					   file_name);
-		break;
-	case GNOME_VFS_ERROR_NOT_FOUND:
-		message = g_strdup_printf (_("\"%s\" couldn't be found. Perhaps it has recently been deleted."),
-					   file_name);
-		break;
-	default:
-		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_loading_directory, tell sullivan@eazel.com", 
-			   error, gnome_vfs_result_to_string (error));
-		message = g_strdup_printf (_("Sorry, couldn't display all the contents of \"%s\"."), file_name);
+	if (!error_message) {
+		switch (error) {
+		case GNOME_VFS_ERROR_ACCESS_DENIED:
+			message = g_strdup_printf (_("You do not have the permissions necessary to view the contents of \"%s\"."),
+						   file_name);
+			break;
+		case GNOME_VFS_ERROR_NOT_FOUND:
+			message = g_strdup_printf (_("\"%s\" couldn't be found. Perhaps it has recently been deleted."),
+						   file_name);
+			break;
+		default:
+			/* We should invent decent error messages for every case we actually experience. */
+			g_warning ("Hit unhandled case %d (%s) in fm_report_error_loading_directory", 
+				   error, gnome_vfs_result_to_string (error));
+			message = g_strdup_printf (_("Sorry, couldn't display all the contents of \"%s\"."), file_name);
+		}
+	} else {
+		message = g_strdup (error_message);
 	}
 
-	eel_show_error_dialog (message, _("Error Displaying Folder"), parent_window);
+	eel_show_error_dialog (_("The folder contents could not be displayed."), message, parent_window);
 
 	g_free (file_name);
 	g_free (message);
@@ -130,7 +134,7 @@ fm_report_error_renaming_file (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_renaming_file, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_renaming_file", 
 			   error, gnome_vfs_result_to_string (error));
 		/* fall through */
 	case GNOME_VFS_ERROR_GENERIC:
@@ -141,7 +145,7 @@ fm_report_error_renaming_file (NautilusFile *file,
 	g_free (original_name_truncated);
 	g_free (new_name_truncated);
 
-	eel_show_error_dialog (message, _("Renaming Error"), parent_window);
+	eel_show_error_dialog (_("The item could not be renamed."), message, parent_window);
 	g_free (message);
 }
 
@@ -170,14 +174,14 @@ fm_report_error_setting_group (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_group, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_group", 
 			   error, gnome_vfs_result_to_string (error));
 		file_name = nautilus_file_get_display_name (file);
 		message = g_strdup_printf (_("Sorry, couldn't change the group of \"%s\"."), file_name);
 		g_free (file_name);
 	}
 
-	eel_show_error_dialog (message, _("Error Setting Group"), parent_window);
+	eel_show_error_dialog (_("The group could not be changed."), message, parent_window);
 
 	g_free (file_name);
 	g_free (message);
@@ -204,12 +208,12 @@ fm_report_error_setting_owner (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_owner, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_owner", 
 			   error, gnome_vfs_result_to_string (error));
 		message = g_strdup_printf (_("Sorry, couldn't change the owner of \"%s\"."), file_name);
 	}
 
-	eel_show_error_dialog (message, _("Error Setting Owner"), parent_window);
+	eel_show_error_dialog (_("The owner could not be changed."), message, parent_window);
 
 	g_free (file_name);
 	g_free (message);
@@ -236,12 +240,12 @@ fm_report_error_setting_permissions (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_permissions, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_permissions", 
 			   error, gnome_vfs_result_to_string (error));
 		message = g_strdup_printf (_("Sorry, couldn't change the permissions of \"%s\"."), file_name);
 	}
 
-	eel_show_error_dialog (message, _("Error Setting Permissions"), parent_window);
+	eel_show_error_dialog (_("The permissions could not be changed."), message, parent_window);
 
 	g_free (file_name);
 	g_free (message);
@@ -254,37 +258,39 @@ rename_callback (NautilusFile *file, GnomeVFSResult result, gpointer callback_da
 
 	g_assert (NAUTILUS_IS_FILE (file));
 	g_assert (callback_data == NULL);
-	name = gtk_object_get_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	name = g_object_get_data (G_OBJECT (file), NEW_NAME_TAG);
 	g_assert (name != NULL);
 
 	/* If rename failed, notify the user. */
 	fm_report_error_renaming_file (file, name, result, NULL);
 
-	cancel_rename (file);
+	cancel_rename (file, TRUE);
 }
 
 static void
 cancel_rename_callback (gpointer callback_data)
 {
-	cancel_rename (NAUTILUS_FILE (callback_data));
+	cancel_rename (NAUTILUS_FILE (callback_data), FALSE);
 }
 
 static void
-cancel_rename (NautilusFile *file)
+cancel_rename (NautilusFile *file, gboolean stop_timer)
 {
 	char *name;
 
-	name = gtk_object_get_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	name = g_object_get_data (G_OBJECT (file), NEW_NAME_TAG);
 	if (name == NULL) {
 		return;
 	}
 
 	/* Cancel both the rename and the timed wait. */
 	nautilus_file_cancel (file, rename_callback, NULL);
-	eel_timed_wait_stop (cancel_rename_callback, file);
+	if (stop_timer) {
+		eel_timed_wait_stop (cancel_rename_callback, file);
+	}
 
 	/* Let go of file name. */
-	gtk_object_remove_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	g_object_set_data (G_OBJECT (file), NEW_NAME_TAG, NULL);
 }
 
 void
@@ -297,13 +303,13 @@ fm_rename_file (NautilusFile *file,
 	g_return_if_fail (new_name != NULL);
 
 	/* Stop any earlier rename that's already in progress. */
-	cancel_rename (file);
+	cancel_rename (file, TRUE);
 
 	/* Attach the new name to the file. */
-	gtk_object_set_data_full (GTK_OBJECT (file),
-				  NEW_NAME_TAG,
-				  g_strdup (new_name),
-				  g_free);
+	g_object_set_data_full (G_OBJECT (file),
+				NEW_NAME_TAG,
+				g_strdup (new_name),
+				g_free);
 
 	/* Start the timed wait to cancel the rename. */
 	old_name = nautilus_file_get_display_name (file);
@@ -311,9 +317,8 @@ fm_rename_file (NautilusFile *file,
 					old_name,
 					new_name);
 	g_free (old_name);
-	eel_timed_wait_start (cancel_rename_callback, file,
-				   _("Cancel Rename?"), wait_message,
-				   NULL); /* FIXME bugzilla.gnome.org 42395: Parent this? */
+	eel_timed_wait_start (cancel_rename_callback, file, wait_message, 
+			      NULL); /* FIXME bugzilla.gnome.org 42395: Parent this? */
 	g_free (wait_message);
 
 	/* Start the rename. */
