@@ -833,6 +833,7 @@ fm_tree_view_create_folder_cb (GtkWidget *menu_item,
 
 	parent_uri = nautilus_file_get_uri (view->details->popup_file);
 	nautilus_file_operations_new_folder (GTK_WIDGET (view->details->tree_widget),
+					     NULL,
 					     parent_uri,
 					     new_folder_done, view->details->tree_widget);
 
@@ -1060,11 +1061,9 @@ volume_or_drive_unmounted_callback (gboolean succeeded,
 	eject = GPOINTER_TO_INT (data);
 	if (!succeeded) {
 		if (eject) {
-			eel_show_error_dialog_with_details (error, NULL, 
-			                                    _("Eject Error"), detailed_error, NULL);
+			eel_show_error_dialog_with_details (error, NULL, detailed_error, NULL);
 		} else {
-			eel_show_error_dialog_with_details (error, NULL, 
-			                                    _("Unmount Error"), detailed_error, NULL);
+			eel_show_error_dialog_with_details (error, NULL, detailed_error, NULL);
 		}
 	}
 }
@@ -1245,7 +1244,7 @@ create_tree (FMTreeView *view)
 		 G_CALLBACK (row_loaded_callback),
 		 view, G_CONNECT_AFTER);
 	home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-	fm_tree_model_add_root_uri (view->details->child_model, home_uri, _("Home Folder"), "gnome-home", NULL);
+	fm_tree_model_add_root_uri (view->details->child_model, home_uri, _("Home Folder"), "gnome-fs-home", NULL);
 	g_free (home_uri);
 	fm_tree_model_add_root_uri (view->details->child_model, "file:///", _("File System"), "gnome-fs-directory", NULL);
 #ifdef NOT_YET_USABLE
