@@ -1123,18 +1123,10 @@ button_data_free (ButtonData *button_data)
 static const char *
 get_dir_name (ButtonData *button_data)
 {
-        if (button_data->type == HOME_BUTTON) {
-		if (!desktop_is_home) {
-                	return _("Home");
-		} else {
-			return _("Desktop");
-		}
+        if (button_data->type == DESKTOP_BUTTON || (button_data->type == HOME_BUTTON && desktop_is_home)) {
+		return _("Desktop");
 	} else {
-        	if (button_data->type == DESKTOP_BUTTON) {
-                	return _("Desktop");
-		} else {
-	                return button_data->dir_name;
-		}
+		return button_data->dir_name;
 	}
 }
 
@@ -1505,11 +1497,15 @@ static char *
 get_display_name_for_folder (const char *file_path)
 {
 	GnomeVFSURI *vfs_uri;
+	NautilusFile *file;
 	char *name;
 
 	vfs_uri = gnome_vfs_uri_new (file_path);
  	if (vfs_uri == NULL) {
-		return NULL;
+		file = nautilus_file_get (file_path);
+		name = nautilus_file_get_display_name (file);
+		nautilus_file_unref (file);
+		return name;
 	}
 	name = nautilus_get_uri_shortname_for_display (vfs_uri);
 	gnome_vfs_uri_unref (vfs_uri);	
